==> qt-creator-opensource-src-4.0.2.zip: qt-creator-opensource-src-4.0.2/src/libs/modelinglib/qmt/infrastructure/contextmenuaction.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMT_CONTEXTMENUACTION_H
#define QMT_CONTEXTMENUACTION_H

#include <QAction>

namespace qmt {

class ContextMenuAction : public QAction
{
public:
    ContextMenuAction(const QString &label, const QString &id, QObject *parent = 0);
    ContextMenuAction(const QString &label, const QString &id, const QKeySequence &shortcut,
                      QObject *parent = 0);
    ~ContextMenuAction() override;

    QString id() const { return m_id; }

private:
    QString m_id;
};

} // namespace qmt

#endif // QMT_CONTEXTMENUACTION_H

==> qt-creator-opensource-src-4.6.2.zip: qt-creator-opensource-src-4.6.2/src/libs/modelinglib/qmt/infrastructure/contextmenuaction.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "qmt_global.h"
#include <QAction>

namespace qmt {

class QMT_EXPORT ContextMenuAction : public QAction
{
public:
    ContextMenuAction(const QString &label, const QString &id, QObject *parent = nullptr);
    ContextMenuAction(const QString &label, const QString &id, const QKeySequence &shortcut,
                      QObject *parent = nullptr);
    ~ContextMenuAction() override;

    QString id() const { return m_id; }

private:
    QString m_id;
};

} // namespace qmt
